It takes four parameters as the coordinates of two points at the beginning and end of a straight line, and calculates the area exactly below the line (between the line and the x-axis).
calc.area.below.line(x1, x2, y1, y2)A float.
Float values, indicating the first coordinates of start and end points, respectively.
Float values, indicating the second coordinates of start and end points, respectively.