It calculates the positive and negative areas between CDFs. The positive is where both CDF and SSD of the first prospect is larger, and vice versa for the negative case.
pos.neg.area.assd.ll(sd.obj)A list, including three elements corresponding to the positive and negative areas, respectively, and the area vector at the end.
StochasticDominance object.
[modif.outcome.ssd.calc()] for more details.